@@ -1,6 +1,6 @@
 
 /*
- * Copyright (c) 2019, Redis Labs
+ * Copyright (c) 2019, Redis Ltd.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,8 +28,8 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef __REDIS_CONNECTION_H
-#define __REDIS_CONNECTION_H
+#ifndef VALKEY_CONNECTION_H
+#define VALKEY_CONNECTION_H
 
 #include <errno.h>
 #include <stdio.h>
@@ -38,9 +38,8 @@
 
 #include "ae.h"
 
-#define CONN_INFO_LEN   32
+#define CONN_INFO_LEN 32
 #define CONN_ADDR_STR_LEN 128 /* Similar to INET6_ADDRSTRLEN, hoping to handle other protocols. */
-#define MAX_ACCEPTS_PER_CALL 1000
 
 struct aeEventLoop;
 typedef struct connection connection;
@@ -55,13 +54,13 @@ typedef enum {
     CONN_STATE_ERROR
 } ConnectionState;
 
-#define CONN_FLAG_CLOSE_SCHEDULED   (1<<0)      /* Closed scheduled by a handler */
-#define CONN_FLAG_WRITE_BARRIER     (1<<1)      /* Write barrier requested */
+#define CONN_FLAG_CLOSE_SCHEDULED (1 << 0) /* Closed scheduled by a handler */
+#define CONN_FLAG_WRITE_BARRIER (1 << 1)   /* Write barrier requested */
 
-#define CONN_TYPE_SOCKET            "tcp"
-#define CONN_TYPE_UNIX              "unix"
-#define CONN_TYPE_TLS               "tls"
-#define CONN_TYPE_MAX               8           /* 8 is enough to be extendable */
+#define CONN_TYPE_SOCKET "tcp"
+#define CONN_TYPE_UNIX "unix"
+#define CONN_TYPE_TLS "tls"
+#define CONN_TYPE_MAX 8 /* 8 is enough to be extendable */
 
 typedef void (*ConnectionCallbackFunc)(struct connection *conn);
 
@@ -82,13 +81,17 @@ typedef struct ConnectionType {
     int (*listen)(connListener *listener);
 
     /* create/shutdown/close connection */
-    connection* (*conn_create)(void);
-    connection* (*conn_create_accepted)(int fd, void *priv);
+    connection *(*conn_create)(void);
+    connection *(*conn_create_accepted)(int fd, void *priv);
     void (*shutdown)(struct connection *conn);
     void (*close)(struct connection *conn);
 
     /* connect & accept */
-    int (*connect)(struct connection *conn, const char *addr, int port, const char *source_addr, ConnectionCallbackFunc connect_handler);
+    int (*connect)(struct connection *conn,
+                   const char *addr,
+                   int port,
+                   const char *source_addr,
+                   ConnectionCallbackFunc connect_handler);
     int (*blocking_connect)(struct connection *conn, const char *addr, int port, long long timeout);
     int (*accept)(struct connection *conn, ConnectionCallbackFunc accept_handler);
 
@@ -107,6 +110,12 @@ typedef struct ConnectionType {
     int (*has_pending_data)(void);
     int (*process_pending_data)(void);
 
+    /* Postpone update state - with IO threads & TLS we don't want the IO threads to update the event loop events - let
+     * the main-thread do it */
+    void (*postpone_update_state)(struct connection *conn, int);
+    /* Called by the main-thread */
+    void (*update_state)(struct connection *conn);
+
     /* TLS specified methods */
     sds (*get_peer_cert)(struct connection *conn);
 } ConnectionType;
@@ -135,7 +144,8 @@ struct connListener {
     int bindaddr_count;
     int port;
     ConnectionType *ct;
-    void *priv; /* used by connection type specified data */
+    void *priv1; /* used by connection type specified data */
+    void *priv2; /* used by connection type specified data */
 };
 
 /* The connection module does not deal with listening and accepting sockets,
@@ -169,8 +179,11 @@ static inline int connAccept(connection *conn, ConnectionCallbackFunc accept_han
  * If C_ERR is returned, the operation failed and the connection handler shall
  * not be expected.
  */
-static inline int connConnect(connection *conn, const char *addr, int port, const char *src_addr,
-        ConnectionCallbackFunc connect_handler) {
+static inline int connConnect(connection *conn,
+                              const char *addr,
+                              int port,
+                              const char *src_addr,
+                              ConnectionCallbackFunc connect_handler) {
     return conn->type->connect(conn, addr, port, src_addr, connect_handler);
 }
 
@@ -208,7 +221,7 @@ static inline int connWritev(connection *conn, const struct iovec *iov, int iovc
 }
 
 /* Read from the connection, behaves the same as read(2).
- * 
+ *
  * Like read(2), a short read is possible.  A return value of 0 will indicate the
  * connection was closed, and -1 will indicate an error.
  *
@@ -291,14 +304,12 @@ static inline int connAddr(connection *conn, char *ip, size_t ip_len, int *port,
 
 /* Format an IP,port pair into something easy to parse. If IP is IPv6
  * (matches for ":"), the ip is surrounded by []. IP and port are just
- * separated by colons. This the standard to display addresses within Redis. */
+ * separated by colons. This the standard to display addresses within the server. */
 static inline int formatAddr(char *buf, size_t buf_len, char *ip, int port) {
-    return snprintf(buf, buf_len, strchr(ip,':') ?
-           "[%s]:%d" : "%s:%d", ip, port);
+    return snprintf(buf, buf_len, strchr(ip, ':') ? "[%s]:%d" : "%s:%d", ip, port);
 }
 
-static inline int connFormatAddr(connection *conn, char *buf, size_t buf_len, int remote)
-{
+static inline int connFormatAddr(connection *conn, char *buf, size_t buf_len, int remote) {
     char ip[CONN_ADDR_STR_LEN];
     int port;
 
@@ -357,7 +368,7 @@ static inline void *connGetPrivateData(connection *conn) {
  * For sockets, we always return "fd=<fdnum>" to maintain compatibility.
  */
 static inline const char *connGetInfo(connection *conn, char *buf, size_t buf_len) {
-    snprintf(buf, buf_len-1, "fd=%i", conn == NULL ? -1 : conn->fd);
+    snprintf(buf, buf_len - 1, "fd=%i", conn == NULL ? -1 : conn->fd);
     return buf;
 }
 
@@ -379,10 +390,10 @@ static inline sds connGetPeerCert(connection *conn) {
     return NULL;
 }
 
-/* Initialize the redis connection framework */
+/* Initialize the connection framework */
 int connTypeInitialize(void);
 
-/* Register a connection type into redis connection framework */
+/* Register a connection type into the connection framework */
 int connTypeRegister(ConnectionType *ct);
 
 /* Lookup a connection type by type name */
@@ -434,8 +445,7 @@ static inline int connListen(connListener *listener) {
 
 /* Get accept_handler of a connection type */
 static inline aeFileProc *connAcceptHandler(ConnectionType *ct) {
-    if (ct)
-        return ct->accept_handler;
+    if (ct) return ct->accept_handler;
     return NULL;
 }
 
@@ -451,4 +461,16 @@ static inline int connIsTLS(connection *conn) {
     return conn && conn->type == connectionTypeTls();
 }
 
-#endif  /* __REDIS_CONNECTION_H */
+static inline void connUpdateState(connection *conn) {
+    if (conn->type->update_state) {
+        conn->type->update_state(conn);
+    }
+}
+
+static inline void connSetPostponeUpdateState(connection *conn, int on) {
+    if (conn->type->postpone_update_state) {
+        conn->type->postpone_update_state(conn, on);
+    }
+}
+
+#endif /* __REDIS_CONNECTION_H */
