@@ -230,7 +230,8 @@ proc ::valkey_cluster::__dispatch__ {id method args} {
             if {[catch {$link $method {*}$args} e]} {
                 if {$link eq {} || \
                     [string range $e 0 4] eq {MOVED} || \
-                    [string range $e 0 2] eq {I/O} \
+                    [string range $e 0 2] eq {I/O} || \
+		    [string range $e 0 10] eq {CLUSTERDOWN} \
                 } {
                     # MOVED redirection.
                     ::valkey_cluster::__method__refresh_nodes_map $id
@@ -365,3 +366,9 @@ proc ::valkey_cluster::get_slot_from_keys {keys} {
     }
     return $slot
 }
+
+# Check if the server responds with "PONG"
+proc check_server_response {server_id} {
+    # Send a PING command and check if the response is "PONG"
+    return [expr {[catch {R $server_id PING} result] == 0 && $result eq "PONG"}]
+}
